==> 0.0.1.tar.gz: lib/src/chatroom_manager_base.dart <==
import 'package:uuid/uuid.dart';

import 'models.dart';

abstract class StorageBase {
  Future saveRooms(String data);
  String reloadRooms();
}

abstract class MessageBase {
  Future sendMessage(NewRoomEvent event);
}

class Settings {
  Member me;
  StorageBase storage;
  MessageBase messageChannel;

  Settings(
      {required this.me, required this.storage, required this.messageChannel});
}

class ChatroomService {
  static final ChatroomService _singleton = ChatroomService._internal();
  factory ChatroomService() {
    return _singleton;
  }
  ChatroomService._internal();

  late Chat chatRoom;
  late Settings settings;
  late String currentRoomId;

  Future initService(Settings config) async {
    settings = config;
    chatRoom = Chat.make(
        rooms: <Room>[],
        storage: config.storage,
        channel: settings.messageChannel);
    chatRoom.reloadRooms();
  }

  ///
  /// 创建房间
  ///
  Stream<AsyncStatus> createRoom(String roomName, List<Member> members) {
    final me = settings.me;
    final event = NewRoomEvent.make(
        room: Room.make(
            roomId: Uuid().v4().toString(),
            name: roomName,
            createTs: DateTime.now().millisecondsSinceEpoch,
            maxMembers: 10,
            maxMessages: 20,
            password: '',
            members: members,
            messages: []),
        member: me);
    return chatRoom.createRoom(event, []);
  }

  ///
  /// 加入一个已经同步过来的房间
  ///
  void joinRoom(String roomId) {
    final selects = chatRoom.rooms
        .where((element) => element.roomId == roomId)
        .toList(growable: false);
    if (selects.isNotEmpty) {
      currentRoomId = roomId;
      selects.first.joinThisRoom(settings.me.memberKey);
    }
  }

  ///
  /// 加入一个未同步的房间
  ///
  void joinCommingRoom(NewRoomEvent roomEvent) {
    chatRoom.rooms.add(roomEvent.room);
    if (roomEvent.room.members
        .where((element) => element.memberKey == roomEvent.member.memberKey)
        .toList()
        .isEmpty) {
      roomEvent.room.members.add(roomEvent.member);
    }
    currentRoomId = roomEvent.room.roomId;
    roomEvent.room.joinThisRoom(settings.me.memberKey);
  }

  ///
  /// 监听消息流，返回0表示应该中断流
  ///
  Stream<int> roomMessageStream(String roomId) {
    print(chatRoom.rooms.map((e) => e.roomId).toList().toString());
    return chatRoom.rooms
        .where((element) => element.roomId == roomId)
        .first
        .messageStreamController
        .stream;
  }

  void speak(String message) {
    chatRoom.rooms
        .where((element) => element.roomId == currentRoomId)
        .first
        .sendMessage(Message.make(
            messageId: Uuid().v4().toString(),
            sender: settings.me,
            payload: message))
        .toList();
  }

  ///
  /// 房间的消息列表
  ///
  List<Message> roomMessageList(String roomId) {
    return chatRoom.rooms
        .where((element) => element.roomId == roomId)
        .first
        .messages;
  }

  ///
  /// 房间列表
  ///
  List<Room> roomList() {
    return chatRoom.rooms;
  }
}

==> 0.0.3.tar.gz: lib/src/chatroom_manager_base.dart <==
import 'package:uuid/uuid.dart';

import 'models.dart';

abstract class StorageBase {
  Future saveRooms(String data);
  String reloadRooms();
}

abstract class MessageBase {
  Future sendMessage(NewRoomEvent event);
}

class Settings {
  Member me;
  StorageBase storage;
  MessageBase messageChannel;

  Settings(
      {required this.me, required this.storage, required this.messageChannel});
}

class ChatroomService {
  static final ChatroomService _singleton = ChatroomService._internal();
  factory ChatroomService() {
    return _singleton;
  }
  ChatroomService._internal();

  late Chat chatRoom;
  late Settings settings;
  late String currentRoomId;

  Future initService(Settings config) async {
    settings = config;
    chatRoom = Chat.make(
        rooms: <Room>[],
        storage: config.storage,
        channel: settings.messageChannel);
    chatRoom.reloadRooms();
  }

  ///
  /// 创建房间
  ///
  Stream<AsyncStatus> createRoom(
      String roomId, String roomName, List<Member> members) {
    final me = settings.me;
    final event = NewRoomEvent.make(
        room: Room.make(
            roomId: roomId.isNotEmpty ? roomId : Uuid().v4().toString(),
            name: roomName,
            createTs: DateTime.now().millisecondsSinceEpoch,
            maxMembers: 10,
            maxMessages: 20,
            password: '',
            members: members,
            messages: []),
        member: me);
    return chatRoom.createRoom(event, []);
  }

  ///
  /// 加入一个已经同步过来的房间
  ///
  void joinRoom(String roomId) {
    final selects = chatRoom.rooms
        .where((element) => element.roomId == roomId)
        .toList(growable: false);
    if (selects.isNotEmpty) {
      currentRoomId = roomId;
      selects.first.joinThisRoom(settings.me.memberKey);
    }
  }

  ///
  /// 加入一个未同步的房间
  ///
  void joinCommingRoom(NewRoomEvent roomEvent) {
    chatRoom.rooms.add(roomEvent.room);
    if (roomEvent.room.members
        .where((element) => element.memberKey == roomEvent.member.memberKey)
        .toList()
        .isEmpty) {
      roomEvent.room.members.add(roomEvent.member);
    }
    currentRoomId = roomEvent.room.roomId;
    roomEvent.room.joinThisRoom(settings.me.memberKey);
  }

  ///
  /// 监听消息流，返回0表示应该中断流
  ///
  Stream<int> roomMessageStream(String roomId) {
    print(chatRoom.rooms.map((e) => e.roomId).toList().toString());
    return chatRoom.rooms
        .where((element) => element.roomId == roomId)
        .first
        .messageStreamController
        .stream;
  }

  void speak(String message) {
    chatRoom.rooms
        .where((element) => element.roomId == currentRoomId)
        .first
        .sendMessage(Message.make(
            messageId: Uuid().v4().toString(),
            sender: settings.me,
            payload: message))
        .toList();
  }

  ///
  /// 房间的消息列表
  ///
  List<Message> roomMessageList(String roomId) {
    return chatRoom.rooms
        .where((element) => element.roomId == roomId)
        .first
        .messages;
  }

  ///
  /// 房间列表
  ///
  List<Room> roomList() {
    return chatRoom.rooms;
  }
}
